@@ -293,25 +293,26 @@ def search(
     }
     if classifier:
         parameters["c"] = classifier
+    with console.status(f"Searching for {name}..."):
+        response = requests.get(url, headers=headers, params=parameters)
 
-    response = requests.get(url, headers=headers, params=parameters)
+    with console.status("Parsing data..."):
+        soup = bs4.BeautifulSoup(response.text, "lxml")
+        result_list = soup.find(attrs={"aria-label": "Search results"}, class_="unstyled")
+        if not result_list:
+            comment = soup.select(
+                "div.split-layout.split-layout--table.split-layout--wrap-on-tablet > div:nth-child(1) > p"
+            )
+            console.print(f"[bold]{' '.join(comment[0].get_text().split())}[/]")
+            raise typer.Exit()
 
-    soup = bs4.BeautifulSoup(response.text, "lxml")
-    result_list = soup.find(attrs={"aria-label": "Search results"}, class_="unstyled")
-    if not result_list:
-        comment = soup.select(
-            "div.split-layout.split-layout--table.split-layout--wrap-on-tablet > div:nth-child(1) > p"
-        )
-        console.print(f"[bold]{' '.join(comment[0].get_text().split())}[/]")
-        raise typer.Exit()
+        results = [Package(i) for i in result_list.find_all("a", class_="package-snippet")]
 
-    results = [Package(i) for i in result_list.find_all("a", class_="package-snippet")]
-
-    pagination = soup.find(class_="button-group--pagination")
-    if not pagination:
-        amount_of_pages = 1
-    else:
-        amount_of_pages = int(pagination.find_all(["span", "a"])[-2].get_text())
+        pagination = soup.find(class_="button-group--pagination")
+        if not pagination:
+            amount_of_pages = 1
+        else:
+            amount_of_pages = int(pagination.find_all(["span", "a"])[-2].get_text())
 
     table = Table(
         show_header=True,
@@ -329,7 +330,7 @@ def search(
         table.add_row(
             f"{index}.",
             package.version,
-            package.name,
+            f"[link=https://pypi.org/project/{package.name}]{package.name}[/]",
             package.description,
             package.date,
         )
